#!/usr/bin/env python

from distutils.core import setup

setup(name='dbss-anisimov',
      version='1.0',
      description='The best way to convert txt to docx using python',
      author='Nikita_Anisimov',
      author_email='qwerty111111333@mail.ru',
      url='https://github.com/Anisimov1123/txt2docx/blob/main/README.md?plain=1',
      packages=['dbss-anisimov'],
      install_requires=['dropbox']
     )